@@ -4,14 +4,15 @@ package File::HomeDir;
 
 use 5.00503;
 use strict;
-use Carp       ();
-use Config     ();
-use File::Spec ();
+use Carp        ();
+use Config      ();
+use File::Spec  ();
+use File::Which ();
 
 # Globals
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK $IMPLEMENTED_BY};
 BEGIN {
-	$VERSION = '0.89';
+	$VERSION = '0.91';
 
 	# Inherit manually
 	require Exporter;
@@ -75,6 +76,9 @@ if ( $IMPLEMENTED_BY ) {
 } elsif ( $^O eq 'MacOS' ) {
 	# Legacy Mac OS
 	$IMPLEMENTED_BY = 'File::HomeDir::MacOS9';
+} elsif ( File::Which::which('xdg-user-dir') ) {
+	# freedesktop unixes
+	$IMPLEMENTED_BY = 'File::HomeDir::FreeDesktop';
 } else {
 	# Default to Unix semantics
 	$IMPLEMENTED_BY = 'File::HomeDir::Unix';
