@@ -9,7 +9,7 @@ use File::HomeDir::Driver ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.89';
+	$VERSION = '0.91';
 	@ISA     = 'File::HomeDir::Driver';
 }
 
@@ -138,12 +138,6 @@ sub users_videos {
 
 File::HomeDir::Unix - find your home and other directories, on Unix
 
-=head1 DESCRIPTION
-
-This module provides implementations for determining common user
-directories.  In normal usage this module will always be
-used via L<File::HomeDir>.
-
 =head1 SYNOPSIS
 
   use File::HomeDir;
@@ -153,15 +147,15 @@ used via L<File::HomeDir>.
 
   $desktop = File::HomeDir->my_desktop;     # All of these will... 
   $docs    = File::HomeDir->my_documents;   # ...default to home...
-  $music   = File::HomeDir->my_music;       # ...directory at the...
-  $pics    = File::HomeDir->my_pictures;    # ...moment.
+  $music   = File::HomeDir->my_music;       # ...directory
+  $pics    = File::HomeDir->my_pictures;    #
   $videos  = File::HomeDir->my_videos;      #
   $data    = File::HomeDir->my_data;        # 
 
-=head1 TODO
+=head1 DESCRIPTION
 
-=over 4
+This module provides implementations for determining common user
+directories.  In normal usage this module will always be
+used via L<File::HomeDir>.
 
-=item * Add support for common unix desktop and data directories when using KDE / Gnome / ...
-
-=back
+=cut
